@@ -6,5 +6,7 @@ __version__ = pkg_resources.require('monet')[0].version
 _root = os.path.abspath(os.path.dirname(__file__))
 
 from .core import ExpMatrix
-from .latent import MonetModel
-from .denoise import ENHANCE
+from .latent import PCAModel, MonetModel
+from .denoise import EnhanceModel
+
+import scanpy as sc
