@@ -1,7 +1,8 @@
-# Author: Florian Wagner <florian.wagner@uchicago.edu>
+# Author: Florian Wagner <florian.compbio@gmail.com>
 # Copyright (c) 2020 Florian Wagner
 #
 # This file is part of Monet.
 
 from .go_term import GOTerm
 from .gene_ontology import GeneOntology
+from .go_annotation import GOAnnotation
