@@ -1,4 +1,4 @@
-# Author: Florian Wagner <florian.wagner@uchicago.edu>
+# Author: Florian Wagner <florian.compbio@gmail.com>
 # Copyright (c) 2020 Florian Wagner
 #
 # This file is part of Monet.
@@ -7,3 +7,8 @@ from .expression import *
 from .logging import *
 from .files import *
 from .data import *
+from .genes import *
+from .fdr import *
+from .sample import *
+
+from . import annotations
