@@ -1,9 +1,10 @@
-# Author: Florian Wagner <florian.wagner@uchicago.edu>
+# Author: Florian Wagner <florian.compbio@gmail.com>
 # Copyright (c) 2020 Florian Wagner
 #
 # This file is part of Monet.
 
 import logging
+import gzip
 
 import pandas as pd
 
@@ -40,3 +41,14 @@ def save_cell_labels(cell_labels: pd.Series, fpath: str,
     cell_labels.to_csv(fpath, sep='\t')
     _LOGGER.info('Saved labels for %d cells to %s plain-text file.',
                  cell_labels.size, delimited_str)
+
+
+def is_gzip_file(fpath: str) -> bool:
+    is_gzip = True
+    with gzip.open(fpath, 'rb') as fh:
+        try:
+            fh.read(1)
+        except OSError:
+            is_gzip = False
+
+    return is_gzip
