@@ -1,4 +1,4 @@
-# Author: Florian Wagner <florian.wagner@uchicago.edu>
+# Author: Florian Wagner <florian.compbio@gmail.com>
 # Copyright (c) 2020 Florian Wagner
 #
 # This file is part of Monet.
@@ -6,3 +6,6 @@
 from .util import *
 from .cells import *
 from .tsne import *
+from .umap import *
+from .genes import *
+from .heatmap import *
