@@ -1,4 +1,4 @@
-# Author: Florian Wagner <florian.wagner@uchicago.edu>
+# Author: Florian Wagner <florian.compbio@gmail.com>
 # Copyright (c) 2020 Florian Wagner
 #
 # This file is part of Monet.
@@ -13,7 +13,7 @@ import plotly.graph_objs as go
 import pandas as pd
 import numpy as np
 
-from .util import DEFAULT_PLOTLY_COLORS
+from .util import DEFAULT_PLOTLY_COLORS, DEFAULT_GGPLOT_COLORS
 from ..core import ExpMatrix
 from ..latent import PCAModel
 
@@ -32,7 +32,7 @@ def plot_cells(
         cluster_order: List[str] = None,
         cluster_colors: Dict[str, str] = None,
         cluster_labels: Dict[str, str] = None,
-        label_cells: bool = False,
+        labelcells: bool = True,
         width: int = None, height: int = None,
         title: str = None,
         marker_size: int = 4, marker_color: str = None,
@@ -46,13 +46,36 @@ def plot_cells(
         showscale: bool = None,
         colorbar_length: Numeric = 0.4, colorbar_label = None,
         colorbar_font_size: Numeric = None,
-        showlegend: bool = None,
+        showlegend: bool = False,
+        showlabels: bool = True,
+        labelsize: Numeric = 24,
+        offsetlabels: bool = False,
+        colorlabels: bool = False,
+        showaxislabels: bool = True,
+        default_colors: List[str] = None,
+        colorscheme: str = 'plotly',
+        plot_bgcolor: str = 'white',
         legend_title: str = None, legend_font_size: Numeric = None,
+        labelopacity=1.0,
         legend_bgcolor=None,
         legend_xanchor: str = None, legend_x: Numeric = None,
         legend_yanchor: str = None, legend_y: Numeric = None) -> go.Figure:
     """Visualize cell similarities in a scatter plot."""
 
+    valid_colorschemes = ['plotly', 'ggplot']
+
+    if colorscheme not in valid_colorschemes:
+        valid_str = ', '.join(['"%s"' % val for val in valid_colorschemes])
+        raise ValueError(
+            '`colorscheme` must be one of [%s], not "%s"!',
+            valid_str, colorscheme)
+
+    if default_colors is None:
+        if colorscheme == 'plotly':
+            default_colors = DEFAULT_PLOTLY_COLORS
+        elif colorscheme == 'ggplot':
+            default_colors = DEFAULT_GGPLOT_COLORS
+
     if margin is None:
         margin = {}
 
@@ -69,54 +92,60 @@ def plot_cells(
             if not showscale:
                 width = 730
             elif colorbar_label is None:
-                width = 810
+                width = 800
             else:
-                width = 850
+                width = 820
 
     if height is None:
         height = 750
 
     num_cells = scores.shape[0]
-    
+
     if cell_labels is None:
-        cell_labels = pd.Series(index=scores.index, data=['Cells']*num_cells)
+        internal_cell_labels = pd.Series(
+            index=scores.index, data=['Cells']*num_cells)
         if marker_color is None:
             marker_color = 'navy'
         cluster_colors = {'Cells': marker_color}
-    
-    vc = cell_labels.value_counts()
+    else:
+        internal_cell_labels = cell_labels
+
+    vc = internal_cell_labels.value_counts()
     if cluster_order is None:
         cluster_order = vc.index.tolist()
-    
+
     if cluster_colors is None:
         cluster_colors = {}
 
     for i, cluster in enumerate(cluster_order):
         if cluster in cluster_colors:
             continue
-        try:
-            cluster_colors[cluster] = DEFAULT_PLOTLY_COLORS[i]
-        except IndexError:
-            cluster_colors[cluster] = None
+        #try:
+        cluster_colors[cluster] = default_colors[i % len(default_colors)]
+        #except IndexError:
+        #    cluster_colors[cluster] = None
 
     if cluster_labels is None:
-        cluster_labels = dict([cluster, cluster] for cluster in cluster_order)
-    
+        cluster_labels = {}
+
     data = []
     for cluster in cluster_order:
-        label = cluster_labels[cluster]
-        sel = (cell_labels == cluster)
-        
+        try:
+            label = cluster_labels[cluster]
+        except KeyError:
+            label = cluster
+        sel = (internal_cell_labels == cluster)
+
         if profile is not None:
             color=profile.loc[sel].values
         else:
             color=cluster_colors[cluster]
-        
-        sel_scores = scores.loc[sel]
-        x=sel_scores.iloc[:, 0].values
-        y=sel_scores.iloc[:, 1].values
 
-        if label_cells:
+        sel_scores = scores.loc[sel]
+        x = sel_scores.iloc[:, 0].values
+        y = sel_scores.iloc[:, 1].values
+
+        if labelcells:
             text = sel_scores.index.tolist()
         else:
             text = None
@@ -153,7 +182,7 @@ def plot_cells(
         xaxis_label = scores.columns[0]
     if yaxis_label is None:
         yaxis_label = scores.columns[1]
-        
+
     if showticklabels:
         ticks = 'outside'
         default_margin = {
@@ -170,31 +199,91 @@ def plot_cells(
             't': 115,
             'r': 90,
         }
-    
+
     final_margin = default_margin
     final_margin.update(margin)
-    
+
     legend = dict(
-        #title=legend_title,
+        title=legend_title,
         xanchor=legend_xanchor, yanchor=legend_yanchor,
         x=legend_x, y=legend_y,
         font=dict(size=legend_font_size),
         bgcolor=legend_bgcolor)
 
+    annotations = []
+    if cell_labels is not None and showlabels:
+
+        for cluster in cluster_order:
+            if cluster == 'Outliers' or cluster == 'Doublets':
+                continue
+
+            pos = scores.loc[internal_cell_labels == cluster].median(axis=0)
+            xanchor = 'left'
+
+            if offsetlabels:
+                #ptp_x = np.ptp(scores.iloc[:, 0])
+                #offset_x = ptp_x * 0.025
+                #pos.iloc[0] = pos.iloc[0] + offset_x
+                ptp_y = np.ptp(scores.iloc[:, 1])
+                offset_y = ptp_y * 0.035
+                pos.iloc[1] = pos.iloc[1] - offset_y
+
+            try:
+                text = cluster_labels[cluster]
+            except KeyError:
+                text = str(cluster)
+                if text.startswith('Cluster '):
+                    text = text[8:]
+
+            text = ('<span style="text-shadow: '
+                        'white -1px 0px 0px, '
+                        'white 1px -0px 0px, '
+                        'white 0px 1px 0px, '
+                        'white 0px -1px 0px; '
+                        'font-weight: bold">%s</span>') % text
+
+            if colorlabels:
+                font=dict(size=labelsize, color=cluster_colors[cluster])
+            else:
+                font=dict(size=labelsize, color='rgba(0,0,0,%s)' % str(labelopacity))
+
+            ann = go.layout.Annotation(
+                x=pos.iloc[0],
+                y=pos.iloc[1],
+                text=text,
+                xanchor=xanchor,
+                showarrow=False,
+                font=font,
+            )
+            annotations.append(ann)
+
+    # fix for plotly bug where xaxis label is misplaced if shoticklabels=False
+    if not showticklabels:
+        showticklabels = True
+        tickfont = dict(color=plot_bgcolor)
+    else:
+        tickfont = dict()
+
+    if not showaxislabels:
+        titlefont = dict(color=plot_bgcolor)
+    else:
+        titlefont = dict()
+
     layout = go.Layout(
         width=width, height=height, margin=final_margin,
         font=dict(family=font_family, size=font_size),
-        xaxis=dict(linecolor='black', title=xaxis_label,
-                   automargin=automargin, showline=True,
+        xaxis=dict(linecolor='black', title=xaxis_label, titlefont=titlefont,
+                   automargin=automargin, showline=True, tickfont=tickfont,
                    ticks=ticks, ticklen=ticklen, showticklabels=showticklabels),
-        yaxis=dict(linecolor='black', title=yaxis_label,
-                   automargin=automargin, showline=True,
+        yaxis=dict(linecolor='black', title=yaxis_label, titlefont=titlefont,
+                   automargin=automargin, showline=True, tickfont=tickfont,
                    ticks=ticks, ticklen=ticklen, showticklabels=showticklabels),
         title=title,
         legend=legend,
+        annotations=annotations,
         showlegend=showlegend,
-        plot_bgcolor='white')
-    
+        plot_bgcolor=plot_bgcolor)
+
     fig = go.Figure(data=data, layout=layout)
     return fig
 
@@ -205,12 +294,12 @@ def plot_cells_random_order(
         cluster_colors: Dict[str,str] = None,
         seed: int = 0,
         **kwargs) -> go.Figure:
-    
+
     # determine cluster order
     vc = cell_labels.value_counts()
     if cluster_order is None:
         cluster_order = vc.index.tolist()    
-    
+
     # determine cluster colors
     if cluster_colors is None:
         cluster_colors = {}
@@ -236,7 +325,7 @@ def plot_cells_random_order(
         cluster_mapping[cluster] = i / (num_clusters-1)
 
     profile = cell_labels.map(cluster_mapping).astype(np.float64)
-    
+
     # shuffle cells
     scores = scores.sample(axis=0, frac=1.0, random_state=seed, replace=False)
     profile = profile.loc[scores.index]
@@ -248,5 +337,5 @@ def plot_cells_random_order(
     kwargs['showscale'] = False
 
     random_order_fig = plot_cells(scores, profile=profile, **kwargs)
-    
+
     return random_order_fig, regular_fig
